searchData={"items":[{"type":"module","title":"Akin","doc":"Akin\n=======\n\nFunctions for comparing two strings for similarity using a collection of string comparison algorithms for Elixir. \nAlgorithms can be called independently or in total to return a map of metrics.","ref":"Akin.html"},{"type":"module","title":"Options - Akin","doc":"Options accepted in a keyword list (i.e. [ngram_size: 3]).\n\n1. `algorithms`: algorithms to use in comparision. Accepts the name or a keyword list. Default is algorithms/0.\n    1. `metric` - algorithm metric. Default is both\n      - \"string\": uses string algorithms\n      - \"phonetic\": uses phonetic algorithms\n    1. `unit` - algorithm unit. Default is both.\n      - \"whole\": uses algorithms best suited for whole string comparison (distance)\n      - \"partial\": uses algorithms best suited for partial string comparison (substring)\n1. `level` - level for double phonetic matching. Default is \"normal\".\n    - \"strict\": both encodings for each string must match\n    - \"strong\": the primary encoding for each string must match\n    - \"normal\": the primary encoding of one string must match either encoding of other string (default)\n    - \"weak\":   either primary or secondary encoding of one string must match one encoding of other string\n1. `match_at`: an algorith score equal to or above this value is condsidered a match. Default is 0.9\n1. `ngram_size`: number of contiguous letters to split strings into. Default is 2.\n1. `short_length`: qualifies as \"short\" to recieve a shortness boost. Used by Name Metric. Default is 8.\n1. `stem`: boolean representing whether to compare the stemmed version the strings; uses Stemmer. Default `false`","ref":"Akin.html#module-options"},{"type":"function","title":"Akin.compare/3","doc":"Compare two strings. Return map of algorithm metrics.\n\nOptions accepted as a keyword list. If no options are given, default values will be used.","ref":"Akin.html#compare/3"},{"type":"function","title":"Akin.match_name_metrics/3","doc":"Compare a string to a string with logic specific to names. Matches are determined by algorithem\nmetrics equal to or higher than the `match_at` option. Return a list of strings that are a likely\nmatch and their algorithm metrics.","ref":"Akin.html#match_name_metrics/3"},{"type":"function","title":"Akin.match_names/3","doc":"Compare a string against a list of strings.  Matches are determined by algorithem metrics equal to or higher than the\n`match_at` option. Return a list of strings that are a likely match.\n\nFuture Plans \n* _if_ the name part is an initial, give the `initials` score its weight, otherwise reduce it\n* if the `initials` score is significantly higher than the average of the others, reduce the `initials` score to the average of the others \n* add options \n  * \"use_average\", \"top_three\", and/or \"average_of_top_three\"\n  * \"group\" to results into strong matches and weak matches\n  * \"details\" to include the scores in the result list","ref":"Akin.html#match_names/3"},{"type":"function","title":"Akin.match_names_metrics/3","doc":"Compare a string against a list of strings. Matches are determined by algorithem metrics equal to or higher than the\n`match_at` option. Return a list of strings that are a likely match and their algorithm metrics.","ref":"Akin.html#match_names_metrics/3"},{"type":"function","title":"Akin.phonemes/1","doc":"Returns list of unique phonetic encodings produces by the single and\ndouble metaphone algorithms.","ref":"Akin.html#phonemes/1"},{"type":"module","title":"Akin.BagDistance","doc":"Function to calculate the Bag Distance between two strings","ref":"Akin.BagDistance.html"},{"type":"function","title":"Akin.BagDistance.compare/2","doc":"","ref":"Akin.BagDistance.html#compare/2"},{"type":"function","title":"Akin.BagDistance.compare/3","doc":"Calculates the Bag Distance between two given strings","ref":"Akin.BagDistance.html#compare/3"},{"type":"function","title":"Examples - Akin.BagDistance.compare/3","doc":"iex> Akin.BagDistance.compare(%Akin.Corpus{string: \"contact\"}, %Akin.Corpus{string: \"context\"})\n  0.7142857142857143","ref":"Akin.BagDistance.html#compare/3-examples"},{"type":"module","title":"Akin.Corpus","doc":"Struct to hold the multi-form elements which results from normalizing, splitting, and\nstemming the string prior to comparison with another string: MapSet, List, String,\nand Stemmed List.\n\nIn Linguistics, a corpus is a collection of written or spoken eleemtns in machine-readable\n form, made to study linguistic structures, frequencies, etc.","ref":"Akin.Corpus.html"},{"type":"module","title":"Akin.DoubleMetaphone","doc":"Compares two values phonetically and returns a boolean of whether they match\nusing the level in opts. Match calculated using the\n[Double Metaphone Phonetic Algorithm](https://xlinux.nist.gov/dads/HTML/doubleMetaphone.html).","ref":"Akin.DoubleMetaphone.html"},{"type":"function","title":"Akin.DoubleMetaphone.compare/3","doc":"Compare two strings using the double metaphoen algorithm","ref":"Akin.DoubleMetaphone.html#compare/3"},{"type":"module","title":"Akin.Hamming","doc":"Functions to calculate the Hamming Distance between 2 given strings. The Hamming Distance\nis the the smallest number of substitutions needed to change one string into the other string.\n\nIf the strings are not the same length, nil is returned\nIf the string are equal, 0.0 is returned.","ref":"Akin.Hamming.html"},{"type":"function","title":"Akin.Hamming.compare/2","doc":"","ref":"Akin.Hamming.html#compare/2"},{"type":"function","title":"Akin.Hamming.compare/3","doc":"Calculates the Hamming distance between 2 given strings.","ref":"Akin.Hamming.html#compare/3"},{"type":"function","title":"Examples - Akin.Hamming.compare/3","doc":"iex> Akin.Hamming.compare(%Akin.Corpus{string: \"toned\"}, %Akin.Corpus{string: \"roses\"}, [])\n  0.6\n  iex> Akin.Hamming.compare(%Akin.Corpus{string: \"toned\"}, %Akin.Corpus{string: \"peanut\"}, [])\n  nil\n  iex> Akin.Hamming.compare(%Akin.Corpus{string: \"toned\"}, %Akin.Corpus{string: \"toned\"}, [])\n  0.0","ref":"Akin.Hamming.html#compare/3-examples"},{"type":"module","title":"Akin.Helper.SubstringComparison","doc":"Functions to compare strings of different lengths.","ref":"Akin.Helper.SubstringComparison.html"},{"type":"function","title":"Akin.Helper.SubstringComparison.similarity/2","doc":"Determine the substring similarity of two strings as a float between 0 and 1.","ref":"Akin.Helper.SubstringComparison.html#similarity/2"},{"type":"module","title":"Akin.Helpers.InitialsComparison","doc":"Function specific to the comparison and matching of names. Returns matching names and metrics.","ref":"Akin.Helpers.InitialsComparison.html"},{"type":"function","title":"Akin.Helpers.InitialsComparison.cartesian_initials/2","doc":"","ref":"Akin.Helpers.InitialsComparison.html#cartesian_initials/2"},{"type":"function","title":"Akin.Helpers.InitialsComparison.similarity/2","doc":"","ref":"Akin.Helpers.InitialsComparison.html#similarity/2"},{"type":"function","title":"Akin.Helpers.InitialsComparison.similarity/3","doc":"","ref":"Akin.Helpers.InitialsComparison.html#similarity/3"},{"type":"module","title":"Akin.Jaccard","doc":"Functions to calculate the Jaccard similarity between two strings","ref":"Akin.Jaccard.html"},{"type":"function","title":"Akin.Jaccard.compare/3","doc":"Calculates the Jaccard similarity coefficient between two given strings with\nthe specified ngram size","ref":"Akin.Jaccard.html#compare/3"},{"type":"function","title":"Examples - Akin.Jaccard.compare/3","doc":"iex> Akin.Jaccard.compare(%Akin.Corpus{string: \"contact\"}, %Akin.Corpus{string: \"context\"}, [ngram_size: 3])\n  0.25\n  iex> Akin.Jaccard.compare(%Akin.Corpus{string: \"contact\"}, %Akin.Corpus{string: \"context\"}, [ngram_size: 1])\n  0.5555555555555556","ref":"Akin.Jaccard.html#compare/3-examples"},{"type":"module","title":"Akin.JaroWinkler","doc":"Calculates the [Jaro-Winkler Distance](http://en.wikipedia.org/wiki/\nJaro-Winkler_distance) between two strings.","ref":"Akin.JaroWinkler.html"},{"type":"function","title":"Akin.JaroWinkler.compare/2","doc":"","ref":"Akin.JaroWinkler.html#compare/2"},{"type":"function","title":"Akin.JaroWinkler.compare/3","doc":"Calculates the Jaro-Winkler distance between two strings.","ref":"Akin.JaroWinkler.html#compare/3"},{"type":"function","title":"Examples - Akin.JaroWinkler.compare/3","doc":"iex> Akin.JaroWinkler.compare(%Akin.Corpus{string: \"abc\"}, %Akin.Corpus{string: \"\"})\n  0.0\n  iex> Akin.JaroWinkler.compare(%Akin.Corpus{string: \"abc\"}, %Akin.Corpus{string: \"xyz\"})\n  0.0\n  iex> Akin.JaroWinkler.compare(%Akin.Corpus{string: \"compare me\"}, %Akin.Corpus{string: \"compare me\"})\n  1.0\n  iex> Akin.JaroWinkler.compare(%Akin.Corpus{string: \"natural\"}, %Akin.Corpus{string: \"nothing\"})\n  0.5714285714285714","ref":"Akin.JaroWinkler.html#compare/3-examples"},{"type":"function","title":"Akin.JaroWinkler.modify_prefix/2","doc":"Modifies the prefix scale, which gives a more favorable rating to strings\nthat match from the beginning.","ref":"Akin.JaroWinkler.html#modify_prefix/2"},{"type":"function","title":"Akin.JaroWinkler.modify_prefix/4","doc":"","ref":"Akin.JaroWinkler.html#modify_prefix/4"},{"type":"function","title":"Akin.JaroWinkler.score/2","doc":"Score the distance between two strings using String.jaro/2.","ref":"Akin.JaroWinkler.html#score/2"},{"type":"module","title":"Akin.Levenshtein","doc":"Compare two strings for their Levenshtein score.","ref":"Akin.Levenshtein.html"},{"type":"function","title":"Akin.Levenshtein.compare/2","doc":"","ref":"Akin.Levenshtein.html#compare/2"},{"type":"function","title":"Akin.Levenshtein.compare/3","doc":"The score is determined by finding the edit\ndistance: the minimum number of single-character edits needed to change one word into the other.\nThe distance is substracted from 1.0 and then divided by the longest length between the two strings.\nResult is rounded to the tenths.","ref":"Akin.Levenshtein.html#compare/3"},{"type":"module","title":"Akin.ML","doc":"","ref":"Akin.ML.html"},{"type":"function","title":"Akin.ML.tangram_data/0","doc":"","ref":"Akin.ML.html#tangram_data/0"},{"type":"function","title":"Akin.ML.training_data/0","doc":"","ref":"Akin.ML.html#training_data/0"},{"type":"module","title":"Akin.Metaphone","doc":"Calculates the [Metaphone Phonetic Algorithm](http://en.wikipedia.org/wiki/\nMetaphone) metric of two strings.","ref":"Akin.Metaphone.html"},{"type":"function","title":"Akin.Metaphone.compare/2","doc":"","ref":"Akin.Metaphone.html#compare/2"},{"type":"function","title":"Akin.Metaphone.compare/3","doc":"Compares two values phonetically. Return 1 if phonetic representations match, 0 if not.","ref":"Akin.Metaphone.html#compare/3"},{"type":"function","title":"Examples - Akin.Metaphone.compare/3","doc":"iex> Akin.Metaphone.compare(Akin.Util.compose(\"Colorado\"), Akin.Util.compose(\"Kolorado\"))\n  1.0\n  iex> Akin.Metaphone.compare(Akin.Util.compose(\"Moose\"), Akin.Util.compose(\"Elk\"))\n  0.0","ref":"Akin.Metaphone.html#compare/3-examples"},{"type":"module","title":"Akin.Metaphone.Double","doc":"The original Metaphone algorithm was published in 1990 as an improvement over\nthe Soundex algorithm. Like Soundex, it was limited to English-only use. The\nMetaphone algorithm does not produce phonetic representations of an input word\nor name; rather, the output is an intentionally approximate phonetic\nrepresentation. The approximate encoding is necessary to account for the way\nspeakers vary their pronunciations and misspell or otherwise vary words and\nnames they are trying to spell.\n\nThe Double Metaphone phonetic encoding algorithm is the second generation of\nthe Metaphone algorithm. Its implementation was described in the June 2000\nissue of C/C++ Users Journal. It makes a number of fundamental design\nimprovements over the original Metaphone algorithm.\n\nIt is called \"Double\" because it can return both a primary and a secondary code\nfor a string; this accounts for some ambiguous cases as well as for multiple\nvariants of surnames with common ancestry. For example, encoding the name\n\"Smith\" yields a primary code of SM0 and a secondary code of XMT, while the\nname \"Schmidt\" yields a primary code of XMT and a secondary code of SMT--both\nhave XMT in common.\n\nDouble Metaphone tries to account for myriad irregularities in English of\nSlavic, Germanic, Celtic, Greek, French, Italian, Spanish, Chinese, and other\norigin. Thus it uses a much more complex ruleset for coding than its\npredecessor; for example, it tests for approximately 100 different contexts of\nthe use of the letter C alone.\n\nThis script implements the Double Metaphone algorithm (c) 1998, 1999 originally\nimplemented by Lawrence Philips in C++. It was further modified in C++ by Kevin\nAtkinson (http://aspell.net/metaphone/). It was translated to C by Maurice\nAubrey   for use in a Perl extension. A Python version was\ncreated by Andrew Collins on January 12, 2007, using the C source\n(http://www.atomodo.com/code/double-metaphone/metaphone.py/view). This version is\nbased on the python version.\n\nThe next key in the struct is used set to a tuple of the next characters in the\nprimary and secondary codes and to indicate how many characters to move forward\nin the string.  The secondary code letter is given only when it is different than\nthe primary. This is an effort to make the code easier to write and read. The\ndefault action is to add nothing and move to next char.","ref":"Akin.Metaphone.Double.html"},{"type":"function","title":"Akin.Metaphone.Double.check_word_start/1","doc":"Skip silent letters at the start of a word or replace the X if the word starts with\nX as in Xavier with an S","ref":"Akin.Metaphone.Double.html#check_word_start/1"},{"type":"function","title":"Akin.Metaphone.Double.compare/3","doc":"Compare two strings, returning the outcome of the comparison using the\nstrictness of the level.\n\n- \"strict\": both encodings for each string must match\n- \"strong\": the primary encoding for each string must match\n- \"normal\": the primary encoding of one string must match either encoding of other string (default)\n- \"weak\":   either primary or secondary encoding of one string must match one encoding of other string","ref":"Akin.Metaphone.Double.html#compare/3"},{"type":"function","title":"Akin.Metaphone.Double.init/1","doc":"Initialize the struct","ref":"Akin.Metaphone.Double.html#init/1"},{"type":"function","title":"Akin.Metaphone.Double.letter_at_position/2","doc":"","ref":"Akin.Metaphone.Double.html#letter_at_position/2"},{"type":"function","title":"Akin.Metaphone.Double.letter_at_position/3","doc":"","ref":"Akin.Metaphone.Double.html#letter_at_position/3"},{"type":"function","title":"Akin.Metaphone.Double.parse/1","doc":"Iterate input characters","ref":"Akin.Metaphone.Double.html#parse/1"},{"type":"function","title":"Akin.Metaphone.Double.parse/4","doc":"","ref":"Akin.Metaphone.Double.html#parse/4"},{"type":"function","title":"Akin.Metaphone.Double.process/2","doc":"Handle conditional cases for different letters. Update phoenemes in the `next` param\nof the metaphone struct and return the struct.","ref":"Akin.Metaphone.Double.html#process/2"},{"type":"function","title":"Akin.Metaphone.Double.process_initial_vowels/2","doc":"All initial vowels map to \"A\"","ref":"Akin.Metaphone.Double.html#process_initial_vowels/2"},{"type":"function","title":"Akin.Metaphone.Double.substring_compare/3","doc":"Accept two lists. Loop through a cartesian product of the two lists. Using a\nreducer, iterate over the levels. For each level, compare the item\nsets using compare/3. The first, if any, level to return a true value\nfrom compare/3 stops the reducer and percentage of true values found.\nOtherwise the reducer continues. 0 is returned if no comparison returns\ntrue at any level.\n\n- \"strict\": both encodings for each string must match\n- \"strong\": the primary encoding for each string must match\n- \"normal\": the primary encoding of one string must match either encoding of other string (default)\n- \"weak\":   either primary or secondary encoding of one string must match one encoding of other string","ref":"Akin.Metaphone.Double.html#substring_compare/3"},{"type":"module","title":"Akin.Metaphone.Single","doc":"Calculates the [Metaphone Phonetic Algorithm](http://en.wikipedia.org/wiki/\nMetaphone) of a string.","ref":"Akin.Metaphone.Single.html"},{"type":"function","title":"Akin.Metaphone.Single.compute/1","doc":"Returns the Metaphone phonetic version of the provided string.","ref":"Akin.Metaphone.Single.html#compute/1"},{"type":"function","title":"Examples - Akin.Metaphone.Single.compute/1","doc":"iex> Akin.Metaphone.Single.compute(\"z\")\n    \"s\"\n    iex> Akin.Metaphone.Single.compute(\"ztiaz\")\n    \"sxs\"","ref":"Akin.Metaphone.Single.html#compute/1-examples"},{"type":"function","title":"Akin.Metaphone.Single.transcode/1","doc":"Transcodes the rest of the string using the Metaphone algorithm.\n\np = processed values\nc = current character\nr = remaining values\no = output","ref":"Akin.Metaphone.Single.html#transcode/1"},{"type":"function","title":"Akin.Metaphone.Single.transcode/4","doc":"","ref":"Akin.Metaphone.Single.html#transcode/4"},{"type":"function","title":"Akin.Metaphone.Single.transcode_first_character/1","doc":"Transcodes the first character of the string using the Metaphone algorithm.","ref":"Akin.Metaphone.Single.html#transcode_first_character/1"},{"type":"module","title":"Akin.Names","doc":"Function specific to the comparison and matching of names. Returns matching names and metrics.","ref":"Akin.Names.html"},{"type":"function","title":"Akin.Names.compare/3","doc":"Manage the steps of comparing two names. Collect metrics from the algorithms requested\nin the options or the default algorithms. Give weight to the consideration of initials\nand permutation of non-initialed name parts (i.e. \"di constanzo\" in \"j p di constanzo\".\nWeight is applied to the algorithm metrics.","ref":"Akin.Names.html#compare/3"},{"type":"module","title":"Akin.Ngram","doc":"Functions to calculate the ngram distance between two given strings based on this\n[paper](webdocs.cs.ualberta.ca/~kondrak/papers/spire05.pdf)","ref":"Akin.Ngram.html"},{"type":"function","title":"Akin.Ngram.compare/3","doc":"Calculates the ngram similarity between two given strings with a specified\nngram size","ref":"Akin.Ngram.html#compare/3"},{"type":"function","title":"Examples - Akin.Ngram.compare/3","doc":"iex> Akin.Ngram.compare(%Akin.Corpus{string: \"night\"}, %Akin.Corpus{string: \"naght\"}, [ngram_size: 3])\n  0.3333333333333333\n  iex> Akin.Ngram.compare(%Akin.Corpus{string: \"context\"}, %Akin.Corpus{string: \"contact\"}, [ngram_size: 1])\n  0.7142857142857143","ref":"Akin.Ngram.html#compare/3-examples"},{"type":"module","title":"Akin.Overlap","doc":"Implements the Overlap Similarity Metric.","ref":"Akin.Overlap.html"},{"type":"function","title":"Akin.Overlap.compare/3","doc":"Compares two values using the Overlap Similarity metric and returns the\ncoefficient. It takes the ngram size as the third argument.","ref":"Akin.Overlap.html#compare/3"},{"type":"function","title":"Examples - Akin.Overlap.compare/3","doc":"iex> Akin.Overlap.compare(%Akin.Corpus{string: \"compare me\"}, %Akin.Corpus{string: \"to me\"}, [])\n  0.5\n  iex> Akin.Overlap.compare(%Akin.Corpus{string: \"compare me\"}, %Akin.Corpus{string: \"to me\"}, [ngram_size: 1])\n  0.8\n  iex> Akin.Overlap.compare(%Akin.Corpus{string: \"or me\"}, %Akin.Corpus{string: \"me\"}, [ngram_size: 1])\n  1.0","ref":"Akin.Overlap.html#compare/3-examples"},{"type":"module","title":"Akin.SorensenDice","doc":"Functions to calculate the Sorensen-Dice coefficient of two strings.","ref":"Akin.SorensenDice.html"},{"type":"function","title":"Akin.SorensenDice.compare/3","doc":"Calculates the Sorensen-Dice coefficient of two given strings with a\nspecified ngram size passed as the third argument.","ref":"Akin.SorensenDice.html#compare/3"},{"type":"function","title":"Examples - Akin.SorensenDice.compare/3","doc":"iex> Akin.SorensenDice.compare(%Akin.Corpus{string: \"night\"}, %Akin.Corpus{string: \"nacht\"}, [ngram_size: 1])\n  0.6\n  iex> Akin.SorensenDice.compare(%Akin.Corpus{string: \"night\"}, %Akin.Corpus{string: \"nacht\"}, [])\n  0.25\n  iex> Akin.SorensenDice.compare(%Akin.Corpus{string: \"night\"}, %Akin.Corpus{string: \"nacht\"}, [ngram_size: 3])\n  0.0","ref":"Akin.SorensenDice.html#compare/3-examples"},{"type":"module","title":"Akin.Strategy","doc":"Determine whether all comparison functions should use the simple ratio function or\nthe substring ratio function.","ref":"Akin.Strategy.html"},{"type":"function","title":"Akin.Strategy.determine/2","doc":"","ref":"Akin.Strategy.html#determine/2"},{"type":"function","title":"Akin.Strategy.determine/4","doc":"","ref":"Akin.Strategy.html#determine/4"},{"type":"module","title":"Akin.SubstringDoubleMetaphone","doc":"Tokenize the search terms into lists split by white space and compare the cartesian product of the lists.","ref":"Akin.SubstringDoubleMetaphone.html"},{"type":"module","title":"Examples - Akin.SubstringDoubleMetaphone","doc":"iex> left = \"Alice Liddel\"\n  iex> right = \"Liddel, Alice\"\n  iex> Akin.compare(left, right, [algorithms: [\"substring_double_metaphone\"]])\n  %{double_metaphone: 1.0}\n  iex> right = \"Alice P Liddel\"\n  iex> Akin.compare(left, right, [algorithms: [\"substring_double_metaphone\"]])\n  %{substring_double_metaphone: 1.0}\n  iex> right = \"Alice Hargreaves\"\n  iex> Akin.compare(left, right, [algorithms: [\"substring_double_metaphone\"]])\n  %{substring_double_metaphone: 0.5}","ref":"Akin.SubstringDoubleMetaphone.html#module-examples"},{"type":"function","title":"Akin.SubstringDoubleMetaphone.compare/3","doc":"Compares two lists of values phonetically and returns a boolean of whether they match\nreducing all possible matching levels.","ref":"Akin.SubstringDoubleMetaphone.html#compare/3"},{"type":"module","title":"Akin.SubstringSet","doc":"Functions for string comparsion where common words between the strings are compared in sets.\n\nTwo sets\n\n#MapSet \n#MapSet \n\nCommonality\n\n* `common_words = \"alice\"`\n* `common_words_plus_remaining_words_left = \"aliceinwonderland\"`\n* `common_words_plus_remaining_words_right = \"aliceadventuresglasslookingsthethrough\"`\n\nRatio is based on difference in string length\n\n* if words are of similar in length according to Akin.Strategy.determine/2\n  * ratio is String.jaro_distance\n* if words are of dissimilar in length according to Akin.Strategy.determine/2\n  * ratio is Akin.SubstringComparison.similarity/2 * @ratio * scale (determined by Akin.Strategy)\n\nMatch level is based on `opt` :level\n\n* \"normal\" returns average ratio\n* \"weak\" returns maximum ratio","ref":"Akin.SubstringSet.html"},{"type":"function","title":"Akin.SubstringSet.compare/3","doc":"","ref":"Akin.SubstringSet.html#compare/3"},{"type":"module","title":"Akin.SubstringSort","doc":"Use Chunk Sorting to compare two strings using substrings.\n\nRatio is based on difference in string length\n\n* if words are of similar in length according to Akin.Strategy.determine/2\n  * ratio is String.jaro_distance\n* if words are of dissimilar in length according to Akin.Strategy.determine/2\n  * ratio is Akin.SubstringComparison.similarity/2 * @ratio * scale (determined by Akin.Strategy)","ref":"Akin.SubstringSort.html"},{"type":"function","title":"Akin.SubstringSort.compare/3","doc":"This strategy splits the strings on spaces, sorts the list of strings, joins them\ntogether again, and then compares them by applying the Jaro-Winkler distance metric.","ref":"Akin.SubstringSort.html#compare/3"},{"type":"function","title":"Examples - Akin.SubstringSort.compare/3","doc":"iex> Akin.SubstringSort.compare(Akin.Util.compose(\"Alice in Wonderland\"), Akin.Util.compose(\"Alice's Adventures in Wonderland\"))\n  0.63\n\n  iex> StringCompare.SubstringSort.substring_similarity(\"Oscar-Claude Monet\"}, %Akin.Corpus{string: \"Monet, Claude\"}, Akin.Util.compose(\"Alice's Adventures in Wonderland\"))\n  1.0","ref":"Akin.SubstringSort.html#compare/3-examples"},{"type":"behaviour","title":"Akin.Task","doc":"API for all string comparison modules.","ref":"Akin.Task.html"},{"type":"callback","title":"Akin.Task.compare/2","doc":"","ref":"Akin.Task.html#c:compare/2"},{"type":"callback","title":"Akin.Task.compare/3","doc":"","ref":"Akin.Task.html#c:compare/3"},{"type":"module","title":"Akin.Tversky","doc":"Functions to calculate the Tversky index\nbetween two strings.","ref":"Akin.Tversky.html"},{"type":"function","title":"Akin.Tversky.compare/3","doc":"Calculates the Tversky index between two strings. Default alpha is 1\nand beta is 1. ngram_size is a positive integer greater than 0 used\nto tokenize the strings","ref":"Akin.Tversky.html#compare/3"},{"type":"function","title":"Examples - Akin.Tversky.compare/3","doc":"iex> Akin.Tversky.compare(%Akin.Corpus{string: \"contact\"}, %Akin.Corpus{string: \"context\"}, [ngram_size: 4])\n  0.14285714285714285\n  iex> Akin.Tversky.compare(%Akin.Corpus{string: \"contact\"}, %Akin.Corpus{string: \"context\"})\n  0.3333333333333333\n  iex> Akin.Tversky.compare(%Akin.Corpus{string: \"contact\"}, %Akin.Corpus{string: \"context\"}, [ngram_size: 1])\n  0.5555555555555556","ref":"Akin.Tversky.html#compare/3-examples"},{"type":"module","title":"Akin.Util","doc":"Utilities for string preparation, manipulation, comparison, and inspection.","ref":"Akin.Util.html"},{"type":"function","title":"Akin.Util.compose/1","doc":"","ref":"Akin.Util.html#compose/1"},{"type":"function","title":"Akin.Util.compose/2","doc":"Convert string to downcase and unicode standard, standardize whitespace, replace nontext (like emojis), replace punctuation, and convert accents. Then compose a string into a corpus of values for disambiguation. Returns nil when given non-binary.\n)","ref":"Akin.Util.html#compose/2"},{"type":"function","title":"Akin.Util.deduplicate/1","doc":"Removes duplicates from a string (except for c and the final letter). Used in metaphone algorithm.","ref":"Akin.Util.html#deduplicate/1"},{"type":"function","title":"Akin.Util.default_opts/0","doc":"Return the default option values","ref":"Akin.Util.html#default_opts/0"},{"type":"function","title":"Akin.Util.eq?/2","doc":"Compares two values for equality","ref":"Akin.Util.html#eq?/2"},{"type":"function","title":"Akin.Util.intersect/2","doc":"Finds the intersection of two lists.  If Strings are provided, it uses the\ncodepoints of said string.","ref":"Akin.Util.html#intersect/2"},{"type":"function","title":"Akin.Util.is_alphabetic?/1","doc":"Checks to see if a string is alphabetic.","ref":"Akin.Util.html#is_alphabetic?/1"},{"type":"function","title":"Akin.Util.len/1","doc":"Return the length of a string.","ref":"Akin.Util.html#len/1"},{"type":"function","title":"Akin.Util.list_algorithms/0","doc":"Return a list of algorithms.\n\nAccepts a list of algorithm names or a keyword list of options. Default returns all available.\n\n| Options |          |            | Default |\n| ------- | -------- | ---------- | ------- |\n| metric  | \"string\" | \"phonetic\" | both    |\n| unit    | \"whole\"  | \"partial\"    | both    |","ref":"Akin.Util.html#list_algorithms/0"},{"type":"function","title":"Akin.Util.list_algorithms/1","doc":"","ref":"Akin.Util.html#list_algorithms/1"},{"type":"function","title":"Akin.Util.list_algorithms/3","doc":"","ref":"Akin.Util.html#list_algorithms/3"},{"type":"function","title":"Akin.Util.modulize/1","doc":"Camelize input and return as an existing atom, as in referencing functions through apply","ref":"Akin.Util.html#modulize/1"},{"type":"function","title":"Akin.Util.ngram_tokenize/1","doc":"","ref":"Akin.Util.html#ngram_tokenize/1"},{"type":"function","title":"Akin.Util.ngram_tokenize/2","doc":"Tokenizes the input into N-grams (http://en.wikipedia.org/wiki/N-gram).","ref":"Akin.Util.html#ngram_tokenize/2"},{"type":"function","title":"Akin.Util.opts/2","doc":"Take the value for the key from the options. If not present, use the default value from the default\noptions list.","ref":"Akin.Util.html#opts/2"},{"type":"function","title":"Akin.Util.r/1","doc":"Round data types that can be rounded to 2 decimal points.","ref":"Akin.Util.html#r/1"},{"type":"function","title":"Akin.Util.replace_cond/3","doc":"If the conditions are met, replace character with white space. The right condition is when either but noth both the left or right strings contains the character.\n\nAccepts a left string and a right string or a right list of strings and list of characters to replace. Returns a tuple containing left and right with replacements, if replacements were made. Otherwise, the tuple contains the original strings.","ref":"Akin.Util.html#replace_cond/3"},{"type":"module","title":"CSVParse","doc":"","ref":"CSVParse.html"},{"type":"function","title":"CSVParse.dump_to_iodata/1","doc":"","ref":"CSVParse.html#dump_to_iodata/1"},{"type":"function","title":"CSVParse.dump_to_stream/1","doc":"","ref":"CSVParse.html#dump_to_stream/1"},{"type":"function","title":"CSVParse.parse_enumerable/2","doc":"","ref":"CSVParse.html#parse_enumerable/2"},{"type":"function","title":"CSVParse.parse_stream/2","doc":"","ref":"CSVParse.html#parse_stream/2"},{"type":"function","title":"CSVParse.parse_string/2","doc":"","ref":"CSVParse.html#parse_string/2"},{"type":"function","title":"CSVParse.to_line_stream/1","doc":"","ref":"CSVParse.html#to_line_stream/1"},{"type":"module","title":"Word","doc":"","ref":"Word.html"},{"type":"function","title":"Word.get_letters/3","doc":"","ref":"Word.html#get_letters/3"},{"type":"function","title":"Word.init/1","doc":"","ref":"Word.html#init/1"},{"type":"function","title":"Word.is_slavo_germanic?/1","doc":"","ref":"Word.html#is_slavo_germanic?/1"},{"type":"function","title":"Word.normalize/1","doc":"","ref":"Word.html#normalize/1"}],"content_type":"text/markdown"}